summaryrefslogtreecommitdiff
path: root/usr.sbin
diff options
context:
space:
mode:
authorJason McIntyre <jmc@cvs.openbsd.org>2003-11-08 19:42:11 +0000
committerJason McIntyre <jmc@cvs.openbsd.org>2003-11-08 19:42:11 +0000
commitf9f14a9c601ce315abc03482cec3a455d84485be (patch)
treed3f15d5c6a93b645f6b0d392d8f6d35fcc3e2b80 /usr.sbin
parentad31425346725d3d16972902d0a4ba5bfe9d365a (diff)
seperate -> separate; from Jonathon Gray;
ok henning@ dhartmei@
Diffstat (limited to 'usr.sbin')
-rw-r--r--usr.sbin/dhcp/common/parse.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/usr.sbin/dhcp/common/parse.c b/usr.sbin/dhcp/common/parse.c
index 7409727aee3..0d488f30d6e 100644
--- a/usr.sbin/dhcp/common/parse.c
+++ b/usr.sbin/dhcp/common/parse.c
@@ -279,17 +279,17 @@ void parse_lease_time (cfile, timep)
/* No BNF for numeric aggregates - that's defined by the caller. What
this function does is to parse a sequence of numbers separated by
- the token specified in seperator. If max is zero, any number of
+ the token specified in separator. If max is zero, any number of
numbers will be parsed; otherwise, exactly max numbers are
expected. Base and size tell us how to internalize the numbers
once they've been tokenized. */
unsigned char *parse_numeric_aggregate (cfile, buf,
- max, seperator, base, size)
+ max, separator, base, size)
FILE *cfile;
unsigned char *buf;
int *max;
- int seperator;
+ int separator;
int base;
int size;
{
@@ -310,7 +310,7 @@ unsigned char *parse_numeric_aggregate (cfile, buf,
do {
if (count) {
token = peek_token (&val, cfile);
- if (token != seperator) {
+ if (token != separator) {
if (!*max)
break;
if (token != RBRACE && token != LBRACE)
@@ -518,10 +518,10 @@ TIME parse_date (cfile)
if (tm.tm_year > 1900)
tm.tm_year -= 1900;
/* Slash seperating year from month... */
token = next_token (&val, cfile);
if (token != SLASH) {
- parse_warn ("expected slash seperating year from month.");
+ parse_warn ("expected slash separating year from month.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -537,10 +537,10 @@ TIME parse_date (cfile)
}
tm.tm_mon = atoi (val) - 1;
/* Slash seperating month from day... */
token = next_token (&val, cfile);
if (token != SLASH) {
- parse_warn ("expected slash seperating month from day.");
+ parse_warn ("expected slash separating month from day.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -566,10 +566,10 @@ TIME parse_date (cfile)
}
tm.tm_hour = atoi (val);
/* Colon seperating hour from minute... */
token = next_token (&val, cfile);
if (token != COLON) {
- parse_warn ("expected colon seperating hour from minute.");
+ parse_warn ("expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -585,10 +585,10 @@ TIME parse_date (cfile)
}
tm.tm_min = atoi (val);
/* Colon seperating minute from second... */
token = next_token (&val, cfile);
if (token != COLON) {
- parse_warn ("expected colon seperating hour from minute.");
+ parse_warn ("expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -518,10 +518,10 @@ TIME parse_date (cfile)
if (tm.tm_year > 1900)
tm.tm_year -= 1900;
- /* Slash seperating year from month... */
+ /* Slash separating year from month... */
token = next_token (&val, cfile);
if (token != SLASH) {
@@ -537,10 +537,10 @@ TIME parse_date (cfile)
}
tm.tm_mon = atoi (val) - 1;
- /* Slash seperating month from day... */
+ /* Slash separating month from day... */
token = next_token (&val, cfile);
if (token != SLASH) {
@@ -566,10 +566,10 @@ TIME parse_date (cfile)
}
tm.tm_hour = atoi (val);
- /* Colon seperating hour from minute... */
+ /* Colon separating hour from minute... */
token = next_token (&val, cfile);
if (token != COLON) {
@@ -585,10 +585,10 @@ TIME parse_date (cfile)
}
tm.tm_min = atoi (val);
- /* Colon seperating minute from second... */
+ /* Colon separating minute from second... */
token = next_token (&val, cfile);
if (token != COLON) {